from fastapi import APIRouter
from pydantic import BaseModel, field_validator
from typing import List, Optional, Union, Dict, Any

router: APIRouter

class ChatMessage(BaseModel):
    role: str
    content: str

    @field_validator("role")
    @classmethod
    def validate_role(cls, v: str) -> str: ...
    @field_validator("content")
    @classmethod
    def validate_content(cls, v: str) -> str: ...

class ChatCompletionRequest(BaseModel):
    model: str = ...
    messages: List[ChatMessage]
    temperature: float = ...
    max_tokens: Optional[int] = ...
    stream: bool = ...
    debug: bool = ...
    explain_rag: bool = ...

    @field_validator("messages")
    @classmethod
    def validate_messages(cls, v: List[ChatMessage]) -> List[ChatMessage]: ...
    @field_validator("stream")
    @classmethod
    def validate_stream(cls, v: bool) -> bool: ...

class EmbeddingsRequest(BaseModel):
    input: Union[str, List[str]]
    model: str = ...
    encoding_format: str = ...

    @field_validator("input")
    @classmethod
    def validate_input(cls, v: Union[str, List[str]]) -> Union[str, List[str]]: ...
    @field_validator("encoding_format")
    @classmethod
    def validate_encoding_format(cls, v: str) -> str: ...

async def chat_completions(
    request: ChatCompletionRequest, x_request_id: Optional[str] = ...
) -> Dict[str, Any]: ...
async def list_models() -> Dict[str, Any]: ...
async def create_embeddings(
    request: EmbeddingsRequest, x_request_id: Optional[str] = ...
) -> Dict[str, Any]: ...
def _generate_unique_session_id() -> str: ...
